Package Development Cookbook
----------------------------

..
    TODO: reorganize headings

Working with Language
~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   Collect and query sentiment <collecting-and-querying-sentiment>

   Extract an outline from markdown <how-to-extract-outline-from-markdown>

   Auto tag articles and query by tag <article-tagging>


Building Packages
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   Modify an existing package <modifying-an-existing-package>

   Make a package or plugin user-configurable <adding-configuration>

   Receive webhooks from another service <receiving-webhooks>


